# MCP Server Specific Event Names
EVENT_MCP_SERVER_STARTED = "MCP server started"
EVENT_MCP_TOOL_CALLED = "MCP tool called"

# MCP Server Specific Property Names
PROP_TRANSPORT = "transport"
PROP_HOST = "host"
PROP_PORT = "port"
PROP_TOOL_COUNT = "tool_count"
PROP_MCP_SERVER_VERSION = "arcade_mcp_server_version"
PROP_IS_EXECUTION_SUCCESS = "is_execution_success"
PROP_FAILURE_REASON = "failure_reason"
PROP_RESOURCE_SERVER_TYPE = "resource_server_type"
